@@ -161,7 +161,8 @@ def extract_zipfile(import_name, target):
         module = importlib.import_module(module_name)
 
         # Decode and unpack the directory.
-        zipfile.ZipFile(io.BytesIO(base64.b64decode(module.data))).extractall()
+        with zipfile.ZipFile(io.BytesIO(base64.b64decode(module.data))) as zip_file:
+            zip_file.extractall()
 
 
 def main():
