@@ -65,7 +65,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
     def status(self, read_data_flag: bool) -> DwfState:
         """Get the |AnalogIn| instrument state.
 
-        Executing this method initiates a status request to the |AnalogIn| instrument and receives its response.
+        This method performs a status request to the |AnalogIn| instrument and receives its response.
 
         The following methods can be used to retrieve |AnalogIn| instrument status information
         as a result of this call, regardless of the value of the *read_data_flag* parameter:
@@ -508,7 +508,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         in samples/second.
 
         Returns:
-            Tuple[float, float]: The allowed sample frequency range (min, max), in samples/second.
+            Tuple[float, float]: The valid sample frequency range (min, max), in samples/second.
 
         Raises:
             DwfLibraryError: An error occurred while getting the allowed sample frequency range.
@@ -665,7 +665,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         setting the sample buffer size to 4096 implies noise buffer size will be 512.
 
         Returns:
-            int: The currently active noise buffer size. Zero indicates that the noise buffer is disabled.
+            int: The currently configured noise buffer size. Zero indicates that the noise buffer is disabled.
 
         Raises:
             DwfLibraryError: An error occurred while getting the noise buffer size.
@@ -678,10 +678,10 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return noise_buffer_size
 
     def acquisitionModeInfo(self) -> List[DwfAcquisitionMode]:
-        """Return the supported |AnalogIn| acquisition modes.
+        """Get a list of valid |AnalogIn| instrument acquisition modes.
 
         Returns:
-            List[DwfAcquisitionMode]: A list of acquisition modes supported by the |AnalogIn| instrument.
+            List[DwfAcquisitionMode]: A list of valid acquisition modes for the |AnalogIn| instrument.
 
         Raises:
             DwfLibraryError: An error occurred while getting the acquisition mode info.
@@ -838,7 +838,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return channel_filter
 
     def channelRangeInfo(self) -> Tuple[float, float, int]:
-        """Report the possible voltage ranges of the |AnalogIn| input channels, in Volts.
+        """Report the possible voltage range of the |AnalogIn| input channels, in Volts.
 
         The values returned represent ideal values.
         The actual calibrated ranges are channel-dependent.
@@ -849,7 +849,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
 
         Returns:
             Tuple[float, float, int]: The minimum range (Volts), maximum range (Volts),
-            and number of different discrete channel settings of the |AnalogIn| instrument.
+            and number of different discrete channel range settings of the |AnalogIn| instrument.
 
         Raises:
             DwfLibraryError: An error occurred while getting the analog input range setting info.
@@ -991,7 +991,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
 
         Returns:
-            float: The currently active channel offset, in Volts.
+            float: The currently configured channel offset, in Volts.
 
         Raises:
             DwfLibraryError: An error occurred while getting the current channel offset setting.
@@ -1008,7 +1008,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
 
         The channel attenuation is a dimensionless factor.
 
-        This setting is normally used to compensate for probe attenuation.
+        This setting is used to compensate for probe attenuation.
         Many probes have two attenuation settings (e.g., ×1 and ×10).
         The value of this setting should correspond to the value of the probe, or 1 (the default)
         if a direct connection without attenuation is used.
@@ -1036,7 +1036,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
 
         The channel attenuation is a dimensionless factor.
 
-        This setting is normally used to compensate for probe attenuation.
+        This setting is used to compensate for probe attenuation.
         Many probes have two attenuation settings (e.g., ×1 and ×10).
         The value of this setting should correspond to the value of the probe, or 1 (the default)
         if a direct connection without attenuation is used.
@@ -1185,13 +1185,13 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerSourceGet(self) -> DwfTriggerSource:
-        """Get the |AnalogIn| instrument trigger source.
+        """Get the currently selected instrument trigger source.
 
         Returns:
-            DwfTriggerSource: The currently selected trigger source value.
+            DwfTriggerSource: The currently selected trigger source.
 
         Raises:
-            DwfLibraryError: An error occurred while retrieving the active trigger source.
+            DwfLibraryError: An error occurred while retrieving the selected trigger source.
         """
         c_trigger_source = typespec_ctypes.DwfTriggerSource()
         result = self.lib.FDwfAnalogInTriggerSourceGet(self.hdwf, c_trigger_source)
@@ -1201,10 +1201,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return trigger_source
 
     def triggerPositionInfo(self) -> Tuple[float, float, int]:
-        """Get the |AnalogIn| instrument trigger position info.
+        """Get the |AnalogIn| instrument trigger position range.
 
         Returns:
             Tuple[float, float, int]: The valid range of trigger positions that can be configured.
+            The values returned are the *minimum* and *maximum* valid position settings, and the number of steps.
 
         Raises:
             DwfLibraryError: An error occurred while retrieving the trigger position info.
@@ -1230,15 +1231,21 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return (trigger_position_min, trigger_position_max, trigger_position_num_steps)
 
     def triggerPositionSet(self, trigger_position: float) -> None:
-        """Set the |AnalogIn| instrument trigger position.
+        """Set the |AnalogIn| instrument trigger position, in seconds.
 
-        In recording mode, the trigger position is the time, in seconds, relative to the position of the trigger event,
-        of the first valid sample acquired. Negative values indicates times before the trigger time.
+        The meaning of the trigger position depends on the currently selected acquisition mode:
 
-        For example, if the trigger should be in the middle of the acquisition window, this value should be
-        set to -0.5 times the duration of the acquisition window.
+        * In :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAcquisitionMode.Record` acquisition mode, the trigger
+          position is the time of the first valid sample acquired relative to the position of the trigger event.
+          Negative values indicates times before the trigger time.
 
-        In Single acquisition mode, the trigger position is relative to the center of the acquisition window.
+          To place the trigger in the middle of the recording, this value should be set to -0.5 times the duration
+          of the recording.
+
+        * In :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAcquisitionMode.Single` acquisition mode, the trigger
+          position is the trigger event time relative to the center of the acquisition window.
+
+          To place the trigger in the middle of the acquisition buffer, the value should be 0.
 
         Parameters:
             trigger_position (float): The trigger position to be configured, in seconds.
@@ -1251,7 +1258,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerPositionGet(self) -> float:
-        """Get the |AnalogIn| instrument trigger position.
+        """Get the |AnalogIn| instrument trigger position, in seconds.
 
         Returns:
             float: The currently configured trigger position, in seconds.
@@ -1283,10 +1290,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return trigger_position
 
     def triggerAutoTimeoutInfo(self) -> Tuple[float, float, int]:
-        """Get the |AnalogIn| instrument trigger auto-timeout info.
+        """Get the |AnalogIn| instrument trigger auto-timeout range, in seconds.
 
         Returns:
             Tuple[float, float, int]: The valid range of trigger auto-timeout values that can be configured.
+            The values returned are the *minimum* and *maximum* valid auto-timeout settings, and the number of steps.
 
         Raises:
             DwfLibraryError: An error occurred while getting the trigger auto-timeout info.
@@ -1311,21 +1319,24 @@ class AnalogIn(AbstractDwfDeviceSubApi):
 
         return (auto_timeout_min, auto_timeout_max, auto_timeout_num_steps)
 
-    def triggerAutoTimeoutSet(self, trigger_autotimeout: float) -> None:
-        """Set the |AnalogIn| instrument trigger auto-timeout value.
+    def triggerAutoTimeoutSet(self, trigger_auto_timeout: float) -> None:
+        """Set the |AnalogIn| instrument trigger auto-timeout value, in seconds.
+
+        When set to 0, the trigger auto-timeout feature is disabled, corresponding to *Normal* acquisition
+        mode on desktop oscilloscopes.
 
         Parameters:
-            trigger_autotimeout (float): The auto timeout setting, in seconds.
+            trigger_auto_timeout (float): The auto timeout setting, in seconds.
 
         Raises:
             DwfLibraryError: An error occurred while setting the trigger auto-timeout value.
         """
-        result = self.lib.FDwfAnalogInTriggerAutoTimeoutSet(self.hdwf, trigger_autotimeout)
+        result = self.lib.FDwfAnalogInTriggerAutoTimeoutSet(self.hdwf, trigger_auto_timeout)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def triggerAutoTimeoutGet(self) -> float:
-        """Get the |AnalogIn| instrument trigger auto-timeout value.
+        """Get the |AnalogIn| instrument trigger auto-timeout value, in seconds.
 
         Returns:
             float: The currently configured auto-timeout value, in seconds.
@@ -1367,13 +1378,14 @@ class AnalogIn(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def triggerHoldOffInfo(self) -> Tuple[float, float, int]:
-        """Get |AnalogIn| trigger detector holdoff info, in seconds.
+        """Get the |AnalogIn| trigger detector holdoff range, in seconds.
 
-        The trigger holdoff setting is the minimum time (in seconds) for a trigger to be
-        recognized after a previous trigger.
+        The trigger holdoff setting is the minimum time (in seconds) that should pass for a trigger to be
+        recognized by the trigger detector after a previous trigger event.
 
         Returns:
-            Tuple[float, float, int]: The valid range of trigger holdoff values that can be configured.
+            Tuple[float, float, int]: The valid range of trigger detector holdoff values that can be configured.
+            The values returned are the *minimum* and *maximum* valid holdoff settings, and the number of steps.
 
         Raises:
             DwfLibraryError: An error occurred while getting the trigger holdoff info.
@@ -1400,20 +1412,22 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return (trigger_holdoff_min, trigger_holdoff_max, trigger_holdoff_num_steps)
 
     def triggerHoldOffSet(self, trigger_holdoff: float) -> None:
-        """Set the |AnalogIn| trigger detector  holdoff value, in seconds.
+        """Set the |AnalogIn| trigger detector holdoff value, in seconds.
 
         Parameters:
-            trigger_holdoff (float): The holdoff setting, in seconds.
+            trigger_holdoff (float): The trigger holdoff setting, in seconds.
+
+        The value 0 disables the trigger detector holdoff feature.
 
         Raises:
-            DwfLibraryError: An error occurred while setting the trigger holdoff value.
+            DwfLibraryError: An error occurred while setting the trigger detector holdoff value.
         """
         result = self.lib.FDwfAnalogInTriggerHoldOffSet(self.hdwf, trigger_holdoff)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def triggerHoldOffGet(self) -> float:
-        """Get the current |AnalogIn| trigger detector holdoff value, in seconds.
+        """Get the current |AnalogIn| trigger holdoff value, in seconds.
 
         Returns:
             float: The currently configured trigger holdoff value, in seconds.
@@ -1429,13 +1443,16 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return trigger_holdoff
 
     def triggerTypeInfo(self) -> List[DwfAnalogInTriggerType]:
-        """Get the |AnalogIn| trigger detector trigger type info.
+        """Get the valid |AnalogIn| trigger detector trigger-type values.
+
+        This setting determines the type of event recognized by the |AnalogIn| trigger detector as a trigger.
+        Possible types includes *Edge*, *Pulse*, *Transition*, and *Window*.
 
         Returns:
-            List[DwfAnalogInTriggerType]: A list of trigger types that can be configured.
+            List[DwfAnalogInTriggerType]: A list of trigger detector trigger-types that can be configured.
 
         Raises:
-            DwfLibraryError: An error occurred while getting the trigger type info.
+            DwfLibraryError: An error occurred while getting the trigger detector trigger-type info.
         """
         c_trigger_type_bitset = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogInTriggerTypeInfo(self.hdwf, c_trigger_type_bitset)
@@ -1447,26 +1464,26 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return trigger_type_list
 
     def triggerTypeSet(self, trigger_type: DwfAnalogInTriggerType) -> None:
-        """Set the |AnalogIn| trigger detector trigger type.
+        """Set the |AnalogIn| trigger detector trigger-type.
 
         Parameters:
-            trigger_type (DwfAnalogInTriggerType): The trigger type to be configured.
+            trigger_type (DwfAnalogInTriggerType): The trigger detector trigger-type to be configured.
 
         Raises:
-            DwfLibraryError: An error occurred while setting the trigger type.
+            DwfLibraryError: An error occurred while setting the trigger detector trigger-type.
         """
         result = self.lib.FDwfAnalogInTriggerTypeSet(self.hdwf, trigger_type.value)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def triggerTypeGet(self) -> DwfAnalogInTriggerType:
-        """Get the |AnalogIn| trigger detector trigger type.
+        """Get the currently configured |AnalogIn| trigger detector trigger-type.
 
         Returns:
-            DwfAnalogInTriggerType: The currently configured trigger type.
+            DwfAnalogInTriggerType: The currently configured trigger detector trigger-type.
 
         Raises:
-            DwfLibraryError: An error occurred while getting the trigger type.
+            DwfLibraryError: An error occurred while getting the trigger detector trigger-type.
         """
         c_trigger_type = typespec_ctypes.DwfAnalogInTriggerType()
         result = self.lib.FDwfAnalogInTriggerTypeGet(self.hdwf, c_trigger_type)
@@ -1476,17 +1493,17 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return trigger_type
 
     def triggerChannelInfo(self) -> Tuple[int, int]:
-        """Get the |AnalogIn| trigger detector channel info.
+        """Get the |AnalogIn| trigger detector channel range.
 
-        The |AnalogIn| trigger detector is sensitive to a specific channel.
+        The |AnalogIn| trigger detector monitors a specific analog in channel for trigger events.
         This method returns the range of valid analog input channels that can be configured
         as the |AnalogIn| trigger detector channel.
 
         Returns:
-            Tuple[int, int]: A two-element tuple (min_channel_index, max_channel_index).
+            Tuple[int, int]: The first and last channel that can be used as trigger detector channels.
 
         Raises:
-            DwfLibraryError: An error occurred while getting the trigger channel info.
+            DwfLibraryError: An error occurred while getting the trigger detector channel range.
         """
         c_trigger_channel_index_min = typespec_ctypes.c_int()
         c_trigger_channel_index_max = typespec_ctypes.c_int()
@@ -1503,13 +1520,13 @@ class AnalogIn(AbstractDwfDeviceSubApi):
     def triggerChannelSet(self, trigger_channel_index: int) -> None:
         """Set the |AnalogIn| trigger detector channel.
 
-        This is the analog input channel that the |AnalogIn| trigger detector is sensitive to.
+        This is the analog input channel that the |AnalogIn| trigger detector monitors for trigger events.
 
         Parameters:
-            trigger_channel_index (int): The trigger channel to be selected.
+            trigger_channel_index (int): The trigger detector channel to be selected.
 
         Raises:
-            DwfLibraryError: An error occurred while setting the trigger channel.
+            DwfLibraryError: An error occurred while setting the trigger detector channel.
         """
         result = self.lib.FDwfAnalogInTriggerChannelSet(self.hdwf, trigger_channel_index)
         if result != RESULT_SUCCESS:
@@ -1518,13 +1535,13 @@ class AnalogIn(AbstractDwfDeviceSubApi):
     def triggerChannelGet(self) -> int:
         """Get the |AnalogIn| trigger detector channel.
 
-        This is the analog input channel that the |AnalogIn| trigger detector is sensitive to.
+        This is the analog input channel that the |AnalogIn| trigger detector monitors for trigger events.
 
         Returns:
             int: The currently configured trigger detector channel.
 
         Raises:
-            DwfLibraryError: An error occurred while getting the trigger channel.
+            DwfLibraryError: An error occurred while getting the trigger detector channel.
         """
         c_trigger_channel_index = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogInTriggerChannelGet(self.hdwf, c_trigger_channel_index)
@@ -1534,13 +1551,13 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return trigger_channel_index
 
     def triggerFilterInfo(self) -> List[DwfAnalogInFilter]:
-        """Get |AnalogIn| trigger detector filter info.
+        """Get a list of valid |AnalogIn| trigger detector filter values.
 
         Returns:
-            List[DwfAnalogInFilter]: A list of filters that can be configured for the trigger.
+            List[DwfAnalogInFilter]: A list of filters that can be configured for the trigger detector channel.
 
         Raises:
-            DwfLibraryError: An error occurred while getting the trigger filter info.
+            DwfLibraryError: An error occurred while getting the valid trigger detector channel filter values.
         """
         c_trigger_filter_bitset = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogInTriggerFilterInfo(self.hdwf, c_trigger_filter_bitset)
@@ -1552,26 +1569,26 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return trigger_filter_list
 
     def triggerFilterSet(self, trigger_filter: DwfAnalogInFilter) -> None:
-        """Set the |AnalogIn| trigger detector filter.
+        """Set the |AnalogIn| trigger detector channel filter.
 
         Parameters:
-            trigger_filter (DwfAnalogInFilter): The trigger filter to be selected.
+            trigger_filter (DwfAnalogInFilter): The trigger detector channel filter to be selected.
 
         Raises:
-            DwfLibraryError: An error occurred while setting the trigger filter.
+            DwfLibraryError: An error occurred while setting the trigger detector channel filter.
         """
         result = self.lib.FDwfAnalogInTriggerFilterSet(self.hdwf, trigger_filter.value)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def triggerFilterGet(self) -> DwfAnalogInFilter:
-        """Get the |AnalogIn| trigger detector filter.
+        """Get the |AnalogIn| trigger detector channel filter.
 
         Returns:
-            DwfAnalogInFilter: The currently configured trigger filter.
+            DwfAnalogInFilter: The currently configured trigger detector channel filter.
 
         Raises:
-            DwfLibraryError: An error occurred while getting the trigger filter.
+            DwfLibraryError: An error occurred while getting the trigger detector channel filter.
         """
         c_trigger_filter = typespec_ctypes.DwfAnalogInFilter()
         result = self.lib.FDwfAnalogInTriggerFilterGet(self.hdwf, c_trigger_filter)
@@ -1581,13 +1598,14 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return trigger_filter
 
     def triggerLevelInfo(self) -> Tuple[float, float, int]:
-        """Get the |AnalogIn| trigger detector level info, in Volts.
+        """Get the |AnalogIn| trigger detector valid trigger level range, in Volts.
 
         Returns:
-            Tuple[float, float, int]: The valid range of trigger level values that can be configured.
+            Tuple[float, float, int]: The range of valid trigger levels that can be configured.
+            The values returned are the *minimum* and *maximum* trigger levels in Volts, and the number of steps.
 
         Raises:
-            DwfLibraryError: An error occurred while getting the trigger level info.
+            DwfLibraryError: An error occurred while getting the trigger level range.
         """
         c_trigger_level_min = typespec_ctypes.c_double()
         c_trigger_level_max = typespec_ctypes.c_double()
@@ -1611,7 +1629,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return (trigger_level_min, trigger_level_max, trigger_level_num_steps)
 
     def triggerLevelSet(self, trigger_level: float) -> None:
-        """Set the |AnalogIn| trigger detector level, in Volts.
+        """Set the |AnalogIn| trigger detector trigger-level, in Volts.
 
         Parameters:
             trigger_level (float): The trigger level to be configured, in Volts.
@@ -1624,7 +1642,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerLevelGet(self) -> float:
-        """Get the |AnalogIn| trigger detector level, in Volts.
+        """Get the |AnalogIn| trigger detector trigger-level, in Volts.
 
         Returns:
             float: The currently configured trigger level, in Volts.
@@ -1640,10 +1658,12 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return trigger_level
 
     def triggerHysteresisInfo(self) -> Tuple[float, float, int]:
-        """Get |AnalogIn| trigger detector hysteresis info, in Volts.
+        """Get the |AnalogIn| trigger detector valid hysteresis range, in Volts.
 
         Returns:
             Tuple[float, float, int]: The valid range of trigger hysteresis values that can be configured.
+            The values returned are the *minimum* and *maximum* trigger hysteresis levels in Volts,
+            and the number of steps.
 
         Raises:
             DwfLibraryError: An error occurred while getting the trigger hysteresis info.
@@ -1699,13 +1719,13 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return trigger_hysteresis
 
     def triggerConditionInfo(self) -> List[DwfTriggerSlope]:
-        """Get |AnalogIn| trigger detector condition info.
+        """Get the valid |AnalogIn| trigger detector condition (slope) options.
 
         Returns:
-            List[DwfTriggerSlope]: A list of possible detector condition values.
+            List[DwfTriggerSlope]: A list of valid trigger detector condition (slope) values.
 
         Raises:
-            DwfLibraryError: An error occurred while getting the trigger condition info.
+            DwfLibraryError: An error occurred while getting the valid trigger detector condition values.
         """
         c_trigger_condition_bitset = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogInTriggerConditionInfo(
@@ -1719,10 +1739,10 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return trigger_condition_list
 
     def triggerConditionSet(self, trigger_condition: DwfTriggerSlope) -> None:
-        """Set the |AnalogIn| trigger detector condition.
+        """Set the |AnalogIn| trigger detector condition (slope).
 
         Parameters:
-            trigger_condition (DwfTriggerSlope): The trigger condition to be configured.
+            trigger_condition (DwfTriggerSlope): The trigger detector condition (slope) to be configured.
 
         Raises:
             DwfLibraryError: An error occurred while setting the trigger condition.
@@ -1732,13 +1752,13 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerConditionGet(self) -> DwfTriggerSlope:
-        """Get the |AnalogIn| trigger detector condition.
+        """Get the |AnalogIn| trigger detector condition (slope).
 
         Returns:
-            DwfTriggerSlope: The currently configured trigger condition.
+            DwfTriggerSlope: The currently configured trigger condition (slope).
 
         Raises:
-            DwfLibraryError: An error occurred while setting the trigger condition.
+            DwfLibraryError: An error occurred while setting the trigger condition (slope).
         """
         c_trigger_condition = typespec_ctypes.DwfTriggerSlope()
         result = self.lib.FDwfAnalogInTriggerConditionGet(self.hdwf, c_trigger_condition)
@@ -1748,13 +1768,15 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return DwfTriggerSlope(trigger_condition)
 
     def triggerLengthInfo(self) -> Tuple[float, float, int]:
-        """Get |AnalogIn| trigger detector length info, in seconds.
+        """Get the valid |AnalogIn| trigger detector length range, in seconds.
 
         Returns:
-            Tuple[float, float, int]: The valid range of trigger length values that can be configured.
+            Tuple[float, float, int]: The valid range of trigger detector length values that can be configured.
+            The values returned are the *minimum* and *maximum* trigger detector length values in seconds,
+            and the number of steps.
 
         Raises:
-            DwfLibraryError: An error occurred while getting the trigger length info.
+            DwfLibraryError: An error occurred while getting the trigger length range.
         """
         c_trigger_length_min = typespec_ctypes.c_double()
         c_trigger_length_max = typespec_ctypes.c_double()
@@ -1781,10 +1803,10 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         """Set the |AnalogIn| trigger detector length, in seconds.
 
         Parameters:
-            trigger_length (float): The trigger length to be configured, in seconds.
+            trigger_length (float): The trigger detector length to be configured, in seconds.
 
         Raises:
-            DwfLibraryError: An error occurred while setting the trigger length.
+            DwfLibraryError: An error occurred while setting the trigger detector length.
         """
         result = self.lib.FDwfAnalogInTriggerLengthSet(self.hdwf, trigger_length)
         if result != RESULT_SUCCESS:
@@ -1794,10 +1816,10 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         """Get the |AnalogIn| trigger detector length, in seconds.
 
         Returns:
-            float: The currently configured trigger length, in seconds.
+            float: The currently configured trigger detector length, in seconds.
 
         Raises:
-            DwfLibraryError: An error occurred while getting the trigger length.
+            DwfLibraryError: An error occurred while getting the trigger detector length.
         """
         c_trigger_length = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogInTriggerLengthGet(self.hdwf, c_trigger_length)
@@ -1807,10 +1829,12 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return trigger_length
 
     def triggerLengthConditionInfo(self) -> List[DwfAnalogInTriggerLengthCondition]:
-        """Get |AnalogIn| trigger detector length condition info.
+        """Get a list of valid |AnalogIn| trigger detector length condition values.
+
+        Trigger length condition values include *Less*, *Timeout*, and *More*.
 
         Returns:
-            List[DwfAnalogInTriggerLengthCondition]: The valid trigger length condition values that can be selected.
+            List[DwfAnalogInTriggerLengthCondition]: A list of valid trigger detector length condition values.
 
         Raises:
             DwfLibraryError: An error occurred while getting the trigger length condition info.
@@ -1828,10 +1852,10 @@ class AnalogIn(AbstractDwfDeviceSubApi):
 
         Parameters:
             trigger_length_condition (DwfAnalogInTriggerLengthCondition):
-                The trigger length condition to be configured.
+                The trigger detector length condition to be configured.
 
         Raises:
-            DwfLibraryError: An error occurred while setting the trigger length condition.
+            DwfLibraryError: An error occurred while setting the trigger detector length condition.
         """
         result = self.lib.FDwfAnalogInTriggerLengthConditionSet(
             self.hdwf,
@@ -1843,10 +1867,10 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         """Get the |AnalogIn| trigger detector length condition.
 
         Returns:
-            DwfAnalogInTriggerLengthCondition: The currently configured trigger length condition.
+            DwfAnalogInTriggerLengthCondition: The currently configured trigger detector length condition.
 
         Raises:
-            DwfLibraryError: An error occurred while getting the trigger length condition.
+            DwfLibraryError: An error occurred while getting the trigger detector length condition.
         """
         c_trigger_length_condition = typespec_ctypes.DwfAnalogInTriggerLengthCondition()
         result = self.lib.FDwfAnalogInTriggerLengthConditionGet(
