@@ -57,7 +57,7 @@ class DigitalCan(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def txSet(self, channel_index: int) -> None:
-        """Set the channel where the outgoing (TX) signal will be transmitted.
+        """Set the digital channel (pin) where the outgoing (TX) signal will be transmitted.
 
         Parameters:
             channel_index (int): The channel (digital pin number) on which to transmit data.
@@ -70,7 +70,7 @@ class DigitalCan(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def rxSet(self, channel_index: int) -> None:
-        """Set the channel where the incoming (RX) signal is received.
+        """Set the digital channel (pin) where the incoming (RX) signal is received.
 
         Parameters:
             channel_index (int): The channel (digital pin number) on which to receive data.
