@@ -790,6 +790,9 @@ class DwfAnalogIO(_FixReprMethod, enum.Enum):
     In the C API, this type is called 'ANALOGIO', and it is represented as an *unsigned char*.
     """
 
+    Undocumented = 0
+    """This value is returned in Analog Pro devices, when using 3.16.3 of the DWF library. That is probably a bug."""
+
     Enable = 1
     """The node represent an on/off switch."""
 
